@@ -25,7 +25,7 @@ extern void chomp(char *str);
 extern int percent_encode(char const *in, char *out, int outlen);
 extern void percent_decode(char *buf);
 
-extern int MXCheckFreeSlaves(char const *sockname, char const *qid);
+extern int MXCheckFreeWorkers(char const *sockname, char const *qid);
 extern int MXScanDir(char const *sockname, char const *qid, char const *dir);
 extern int MXCommand(char const *sockname, char const *cmd, char *buf, int len, char const *qid);
 extern int MXRelayOK(char const *sockname, char *msg,
@@ -66,7 +66,7 @@ extern int make_listening_socket(char const *str, int backlog, int must_be_unix)
 extern void do_delay(char const *sleepstr);
 extern int is_localhost(struct sockaddr *);
 extern int remove_local_socket(char const *str);
-extern int write_and_lock_pidfile(char const *pidfile);
+extern int write_and_lock_pidfile(char const *pidfile, char *lockfile, int fd);
 #ifdef EMBED_PERL
 extern int make_embedded_interpreter(char const *progPath,
 				     char const *subFilter,
